Package: casebase
Type: Package
Title: Fitting Flexible Smooth-in-Time Hazards and Risk Functions via
        Logistic and Multinomial Regression
Version: 0.10.6
Date: 2024-08-06
Authors@R: c(
    person("Sahir", "Bhatnagar", , "sahir.bhatnagar@gmail.com", role = c("aut", "cre"),
           comment = "https://sahirbhatnagar.com/"),
    person("Maxime", "Turgeon", , "max.turgeon@umanitoba.ca", role = "aut",
           comment = "https://www.maxturgeon.ca/"),
    person("Jesse", "Islam", , "jesse.islam@mail.mcgill.ca", role = "aut",
           comment = "https://www.jesseislam.com/"),
    person("Olli", "Saarela", , "olli.saarela@utoronto.ca", role = "aut",
           comment = "https://www.dlsph.utoronto.ca/faculty-profile/saarela-olli/"),
    person("James", "Hanley", , "james.hanley@mcgill.ca", role = "aut",
           comment = "https://jhanley.biostat.mcgill.ca/")
  )
Description: Fit flexible and fully parametric hazard regression models to survival data with single event type or multiple 
    competing causes via logistic and multinomial regression. Our formulation allows for arbitrary functional forms 
    of time and its interactions with other predictors for time-dependent hazards and hazard ratios. From the 
    fitted hazard model, we provide functions to readily calculate and plot cumulative incidence and survival 
    curves for a given covariate profile. This approach accommodates any log-linear hazard function of 
    prognostic time, treatment, and covariates, and readily allows for non-proportionality. We also provide 
    a plot method for visualizing incidence density via population time plots. Based on the case-base sampling 
    approach of Hanley and Miettinen (2009) <DOI:10.2202/1557-4679.1125>, Saarela and Arjas (2015) <DOI:10.1111/sjos.12125>, 
    and Saarela (2015) <DOI:10.1007/s10985-015-9352-x>.
Depends: R (>= 3.5.0)
Imports: data.table, ggplot2 (>= 3.4.0), methods, mgcv, stats,
        survival, VGAM
License: MIT + file LICENSE
LazyData: TRUE
Suggests: colorspace, covr, dplyr, eha, glmnet, knitr, lubridate,
        progress, rmarkdown, splines, testthat (>= 3.0.0), visreg
VignetteBuilder: knitr
URL: https://sahirbhatnagar.com/casebase/
BugReports: https://github.com/sahirbhatnagar/casebase/issues
RoxygenNote: 7.3.0
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2024-08-17 22:57:52 UTC; rstudio
Author: Sahir Bhatnagar [aut, cre] (https://sahirbhatnagar.com/),
  Maxime Turgeon [aut] (https://www.maxturgeon.ca/),
  Jesse Islam [aut] (https://www.jesseislam.com/),
  Olli Saarela [aut]
    (https://www.dlsph.utoronto.ca/faculty-profile/saarela-olli/),
  James Hanley [aut] (https://jhanley.biostat.mcgill.ca/)
Maintainer: Sahir Bhatnagar <sahir.bhatnagar@gmail.com>
Repository: CRAN
Date/Publication: 2024-08-17 23:20:05 UTC
Built: R 4.6.0; ; 2026-04-26 06:19:30 UTC; unix
