# Generated by roxygen2: do not edit by hand

S3method(confint,absRiskCB)
S3method(plot,absRiskCB)
S3method(plot,popTime)
S3method(plot,singleEventCB)
S3method(print,absRiskCB)
S3method(print,summary.singleEventCB)
S3method(summary,singleEventCB)
export(absoluteRisk)
export(absoluteRisk.CompRisk)
export(checkArgsEventIndicator)
export(checkArgsTimeEvent)
export(fitSmoothHazard)
export(fitSmoothHazard.fit)
export(hazardPlot)
export(popTime)
export(prepareX)
export(sampleCaseBase)
exportMethods(summary)
import(methods)
importClassesFrom(VGAM,vglm)
importFrom(VGAM,multinomial)
importFrom(VGAM,summaryvglm)
importFrom(VGAM,vglm)
importFrom(data.table,":=")
importFrom(data.table,.N)
importFrom(data.table,as.data.table)
importFrom(data.table,between)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,melt)
importFrom(data.table,rbindlist)
importFrom(data.table,setnames)
importFrom(ggplot2,"%+replace%")
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,rel)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_grey)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(graphics,arrows)
importFrom(graphics,lines)
importFrom(graphics,matplot)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(grid,unit)
importFrom(mgcv,s)
importFrom(mgcv,t2)
importFrom(mgcv,te)
importFrom(mgcv,ti)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,contrasts)
importFrom(stats,delete.response)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,glm.fit)
importFrom(stats,integrate)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,relevel)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,time)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(utils,modifyList)
importMethodsFrom(VGAM,predict)
importMethodsFrom(VGAM,summary)
